`concordance.index` <-
function(x, surv.time, surv.event, weights=NULL, alpha=0.05, outx=FALSE, method=c("conservative", "noether", "nam")) {
	method <- match.arg(method)
	if(!is.null(weights)) {
		if(length(weights) != length(x)) { stop("bad length for parameter weights!") }
	} else { weights <- rep(1,  length(x)) }
	cc.ix <- complete.cases(x, surv.time, surv.event)
	#remove samples whose the weight is equal to 0
	cc.ix <- cc.ix & weights != 0
	x <- x[cc.ix]
	st <- surv.time[cc.ix]
	se <- surv.event[cc.ix]
	weights <- weights[cc.ix]
	N <- length(x)
	
	ch <- dh <- uh <- rph <- NULL
	for(h in 1:N) {
		chj <- dhj <- uhj <- rphj <- 0
		for(j in 1:N) {
			whj <- weights[h] * weights[j]
			if(st[h] < st[j] && se[h] == 1) {
				rphj <- rphj + whj #whj=1 in non-weighted version
				if(x[h] > x[j]) {
					chj <- chj + whj #whj=1 in non-weighted version
				} else if(x[h] < x[j]) {
					dhj <- dhj + whj #whj=1 in non-weighted version
				} else {
					if(outx) {
						uhj <- uhj + whj #whj=1 in non-weighted version
					} else { #ties in x
						dhj <- dhj + whj #whj=1 in non-weighted version
						#dhj <- dhj
					}
				}
			}
			if(st[h] > st[j] && se[j] == 1) {
				rphj <- rphj + whj #whj=1 in non-weighted version
				if(x[h] < x[j]) {
					chj <- chj + whj #whj=1 in non-weighted version
				} else if(x[h] > x[j]) {
					dhj <- dhj + whj #whj=1 in non-weighted version
				} else {
					if(outx) {
						uhj <- uhj + whj #whj=1 in non-weighted version
					} else { #ties in x
						dhj <- dhj + whj #whj=1 in non-weighted version
						#dhj <- dhj
					}
				}
			}
		}
		ch <- c(ch, chj)
		dh <- c(dh, dhj)	
		uh <- c(uh, uhj)
		rph <- c(rph, rphj)
	}
	pc <- (1 / (N * (N - 1))) * sum(ch)
	pd  <- (1 / (N * (N - 1))) * sum(dh)
	cindex <- pc / (pc + pd)
	
	switch(method,
	"noether"={
	pcc <- (1 / (N * (N - 1) * (N - 2))) * sum(ch * (ch - 1))
	pdd <- (1 / (N * (N - 1) * (N - 2))) * sum(dh * (dh - 1))
	pcd <- (1 / (N * (N - 1) * (N - 2))) * sum(ch * dh)
	varp <- (4 / (pc + pd)^4) * (pd^2 * pcc - 2 * pc * pd * pcd + pc^2 * pdd)
	ci <- qnorm(p=alpha / 2, lower.tail=FALSE) * sqrt(varp / N)
	lower <- cindex - ci
	upper <- cindex + ci
	p <- pnorm((cindex - 0.5) / sqrt(varp / N), lower.tail=cindex < 0.5)
	},
	"conservative"={
	C <- cindex
	sum.ch <- sum(ch)
	sum.dh <- sum(dh)
	pc <- (1 / (N * (N - 1))) * sum.ch
	pd  <- (1 / (N * (N - 1))) * sum.dh
	w <- (2 * qnorm(p=alpha / 2, lower.tail=FALSE)^2) / (N * (pc + pd))
	ci <- sqrt(w^2 + 4 * w * C * (1 - C)) / (2 * (1 + w))
	point <- (w + 2 * C) / (2 * (1 + w))
	lower <- point - ci
	upper <- point + ci
	cindex <- C
	p <- NA
	varp <- NA
	},
	"name"={
		stop("method not implemented!")	
	})
	#bound the confidence interval
	lower <- ifelse(lower < 0, 0, lower)
	lower <- ifelse(lower > 1, 1, lower)
	upper <- ifelse(upper < 0, 0, upper)
	upper <- ifelse(upper > 1, 1, upper)
	
	data <- list("x"=x, "surv.time"=surv.time, "surv.event"=surv.event)
	return(list("c.index"=cindex, "se"=sqrt(varp / N), "lower"=lower, "upper"=upper, "p.value"=p, "n"=N, "data"=data))
}

