`td.rocdemo.sca` <-
function(x, surv.time, surv.event, surv.entry=NULL, time, cutpts=NA, markerLabel="unnamed marker", caseLabel="unnamed diagnosis", na.rm=FALSE, verbose=FALSE, span=0, lambda=0, ...) {

	require(ROC)
	require(survivalROC)	
	
	cc.ix <- complete.cases(x, surv.time, surv.event, surv.entry);
   if (!all(cc.ix) && !na.rm) { stop("NA values are present!"); }
   if(verbose) { cat(sprintf("%i cases are removed due to NA values\n",as.integer(sum(!cc.ix)))); }
    
   x <- x[cc.ix];
   surv.time <- surv.time[cc.ix];
   surv.event <- surv.event[cc.ix];
    
   if(!all(sort(unique(surv.event)) == c(0, 1))) { stop("survival event variable must take values 0 or 1"); }
   if(is.na(cutpts)) {
       ux <- unique(sort(x));
       delta <- min(diff(ux))/2;
       cutpts <- c(ux - delta, ux[length(ux)] + delta);
   }
   myrule <- function(x, thresh) { return(ifelse(x > thresh, 1, 0)) };
      if(all(time < surv.time[surv.event == 1])) { return(list("roccobj"=new("rocc", spec=as.numeric(NA), sens=as.numeric(NA), rule=myrule, cuts=cutpts, markerLabel=markerLabel, caseLabel=caseLabel), "time"=time, "survival"=1, "AUC"=1)); }
    
	rocco <- survivalROC(Stime=surv.time, status=surv.event, marker=x, predict.time=time, cut.values=cutpts, entry=surv.entry, span=span, lambda=lambda, ...);
	res <- new("rocc", spec=1-rocco$FP, sens=rocco$TP, rule=myrule, cuts=cutpts, markerLabel=markerLabel, caseLabel=caseLabel);
	data <- list("x"=x, "surv.time"=surv.time, "surv.event"=surv.event)
	return(list("roccobj"=res, "time"=time, "survival"=rocco$Survival, "AUC"=rocco$AUC, "data"=data));
}

