\name{score2proba}
\alias{score2proba}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Function to compute the survival probabilities from a risk score }
\description{
  the function uses either a Cox model or the product-limit estimator to compute the survival probabilities from a risk score for a specific point in time.
}
\usage{
score2proba(data.tr, score, yr, method = c("cox", "prodlim"))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{data.tr}{ the data frame for the training set. This data frame must contain three columns for the times, the event occurence and the risk score. These columns are called "time", "event" and "score" respectively }
  \item{score}{ risk score for the test set }
  \item{yr}{ a point in time for which teh survival probabilities must be computed }
  \item{method}{ method for survival probabliities estimation, either \code{cox} or \code{prodlim} for the Cox model or the product-limit estimator, respectively }
}
%\details{}
\value{
  vector of predicted survival probabilities
}
\references{ D. R. Cox. "Regression Models and Life Tables", \emph{Journal of the Royal Statistical Society Series B}, volume 34, pages 187--220, 1972.
	
	P. K. Andersen, O. Borgan, R. D. Gill and N. Keiding. "Statistical Models Based on Counting Processes", \emph{Springer}, 1993. }
\author{ Benjamin Haibe-Kains }
%\note{}
\seealso{ \code{\link[survival]{cox}}, \code{\link[prodlim]{prodlim}} }
\examples{
set.seed(12345)
age <- rnorm(30, 50, 10)
stime <- rexp(30)
cens <- runif(30,.5,2)
sevent <- stime <= cens
stime <- pmin(stime, cens)
dd <- data.frame("time"=stime, "event"=sevent, "score"=age)
score2proba(data.tr=dd, score=dd$score, yr=1, method="cox")
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ survival }
