\name{td.rocdemo.sca}
\alias{td.rocdemo.sca}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Function to compute time-dependent ROC curves }
\description{
  The function is a wrapper for the \code{\link[survivalROC]{survivalROC}} function in order to compute the time-dependent ROC curves.
}
\usage{
td.rocdemo.sca(x, surv.time, surv.event, surv.entry = NULL, time, cutpts = NA, markerLabel = "unnamed marker", caseLabel = "unnamed diagnosis", na.rm = FALSE, verbose = FALSE, span = 0, lambda = 0, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ vector of risk scores }
  \item{surv.time}{ vector of times to event occurrence }
  \item{surv.event}{ vector of event occurrence indicators }
  \item{surv.entry}{ entry time for the subjects }
  \item{time}{ time point for the ROC curve }
  \item{cutpts}{ cut points for the risk score }
  \item{markerLabel}{ ~~Describe \code{markerLabel} here~~ }
  \item{caseLabel}{ ~~Describe \code{caseLabel} here~~ }
  \item{na.rm}{ \code{TRUE} if the missing values should be removed from the data, \code{FALSE} otherwise }
  \item{verbose}{ verbosity of the function }
  \item{span}{ Span for the NNE, need either lambda or span for NNE }
  \item{lambda}{ smoothing parameter for NNE }
  \item{\dots}{ additional arguments to be passed to the \code{\link[survivalROC]{survivalROC}} function  }
}
%\details{}
\value{
  \item{roccobj }{time-dependent ROC curves in a rocc object}
  \item{time }{time point at which the time-dependent ROC is computed}
  \item{survival }{overall survival at the time point}
  \item{AUC }{Area Under the Curve (AUC) of teh time-dependent ROC curve}
  \item{data }{survival data and risk score used to compute the time-dependent ROC curve}
}
\references{ P. J. Heagerty, T. Lumley and M. S. Pepe. "Time-Dependent ROC Curves for Censored Survival Data and a Diagnostic Marke", \emph{Biometrics}, volume 56, pages 337--344, 2000. }
\author{ Benjamin Haibe-Kains }
%\note{}
\seealso{ \code{\link[survivalROC]{survivalROC}}, \code{link[ROC]{rocdemo.sca}} }
\examples{
set.seed(12345)
age <- rnorm(100, 50, 10)
stime <- rexp(100)
cens <- runif(100,.5,2)
sevent <- stime <= cens
stime <- pmin(stime, cens)
tdroc <- td.rocdemo.sca(x=age, surv.time=stime, surv.event=sevent, time=1, na.rm=TRUE, verbose=FALSE)
##plot the time-dependent ROC curve
plot(1-tdroc$roccobj@spec, tdroc$roccobj@sens, type="l")
lines(x=c(0,1), y=c(0,1), lty=3, col="red")
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ survival }
